Example expression data to demonstrate the functionality of the package: two data sources A and B with 30 patients and 1000 genes each, for each of which we have RMA expression values, (logarithmized) MAS5 expression values, and MAS5 absent/present calls.
Correspondingly, we have six data matrices whose name are constructed as dat[A|B].[rma|mas5|amp].
Usage
data(oligodata)
Arguments
Format
All matrices have genes as rows and samples as columns.
These are small anonymized excerpts from a real breast cancer data set.